summaryrefslogtreecommitdiff
path: root/usr.sbin/rarpd
diff options
context:
space:
mode:
authorIgor Sobrado <sobrado@cvs.openbsd.org>2008-05-17 23:31:53 +0000
committerIgor Sobrado <sobrado@cvs.openbsd.org>2008-05-17 23:31:53 +0000
commit774db206968ab30a7c62d2f168ebe539628e67f9 (patch)
tree50fec1de8900474569902315892975e2da942dc5 /usr.sbin/rarpd
parent650f53e0ab086f348050477f8fe236e8f101b6e9 (diff)
documentation tweaks.
ok (some time ago) jmc@
Diffstat (limited to 'usr.sbin/rarpd')
-rw-r--r--usr.sbin/rarpd/rarpd.86
-rw-r--r--usr.sbin/rarpd/rarpd.c10
2 files changed, 7 insertions, 9 deletions
diff --git a/usr.sbin/rarpd/rarpd.8 b/usr.sbin/rarpd/rarpd.8
index 11054be44ec..a4df79232f1 100644
--- a/usr.sbin/rarpd/rarpd.8
+++ b/usr.sbin/rarpd/rarpd.8
@@ -18,9 +18,9 @@
.\" THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR IMPLIED
.\" WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
.\" MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-.\" @(#) $Id: rarpd.8,v 1.14 2007/05/31 19:20:28 jmc Exp $
+.\" @(#) $Id: rarpd.8,v 1.15 2008/05/17 23:31:52 sobrado Exp $
.\"
-.Dd $Mdocdate: May 31 2007 $
+.Dd $Mdocdate: May 17 2008 $
.Dt RARPD 8
.Os
.Sh NAME
@@ -29,7 +29,7 @@
.Sh SYNOPSIS
.Nm rarpd
.Op Fl adflt
-.Op Ar interface
+.Ar interface
.Sh DESCRIPTION
.Nm
services Reverse ARP requests on the Ethernet connected to
diff --git a/usr.sbin/rarpd/rarpd.c b/usr.sbin/rarpd/rarpd.c
index 39376638d21..3ae0eab4a33 100644
--- a/usr.sbin/rarpd/rarpd.c
+++ b/usr.sbin/rarpd/rarpd.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: rarpd.c,v 1.47 2006/04/02 00:50:42 deraadt Exp $ */
+/* $OpenBSD: rarpd.c,v 1.48 2008/05/17 23:31:52 sobrado Exp $ */
/* $NetBSD: rarpd.c,v 1.25 1998/04/23 02:48:33 mrg Exp $ */
/*
@@ -28,15 +28,14 @@ char copyright[] =
#endif /* not lint */
#ifndef lint
-static char rcsid[] = "$OpenBSD: rarpd.c,v 1.47 2006/04/02 00:50:42 deraadt Exp $";
+static char rcsid[] = "$OpenBSD: rarpd.c,v 1.48 2008/05/17 23:31:52 sobrado Exp $";
#endif
/*
* rarpd - Reverse ARP Daemon
*
* Usage: rarpd -a [-d] [-f] [-l] [-t]
* rarpd [-d] [-f] [-l] [-t] interface
*/
#include <stdio.h>
@@ -258,8 +257,7 @@ init_all(void)
void
usage(void)
{
- (void) fprintf(stderr, "usage: rarpd -a [-dflt]\n");
- (void) fprintf(stderr, " rarpd [-dflt] interface\n");
+ (void) fprintf(stderr, "usage: rarpd [-adflt] interface\n");
exit(1);
}
@@ -28,15 +28,14 @@ char copyright[] =
* rarpd - Reverse ARP Daemon
*
- * Usage: rarpd -a [-d] [-f] [-l] [-t]
- * rarpd [-d] [-f] [-l] [-t] interface
+ * usage: rarpd [-adflt] interface
*/
#include <stdio.h>